@@ -18,8 +18,8 @@
   s.label(x$lQ[, c(xax, yax)], sub = "Q row scores",csub = 2,clabel = 1.25)
   s.corcircle(x$aR, xax, yax, sub = "R axes", csub = 2, clabel = 1.25)
   s.arrow(x$l1, xax = xax, yax = yax, sub = "R Canonical weights", csub = 2, clabel = 1.25)
-  s.corcircle(x$aQ, xax, yax, sub = "Q axes", csub = 2, clabel = 1.25)
   s.arrow(x$c1, xax = xax, yax = yax, sub = "Q Canonical weights", csub = 2, clabel = 1.25)
+  s.corcircle(x$aQ, xax, yax, sub = "Q axes", csub = 2, clabel = 1.25)
   scatterutil.eigen(x$eig, wsel = c(xax, yax))
 }
 
@@ -42,25 +42,25 @@
   else cat("\n\n")
   sumry <- array("", c(3, 4), list(1:3, c("vector", "length", 
                                           "mode", "content")))
-  sumry[1, ] <- c("$eig", length(x$eig), mode(x$eig), "eigen values")
-  sumry[2, ] <- c("$lw", length(x$lw), mode(x$lw), "row weigths (crossed array)")
-  sumry[3, ] <- c("$cw", length(x$cw), mode(x$cw), "col weigths (crossed array)")
+  sumry[1, ] <- c("$eig", length(x$eig), mode(x$eig), "Eigenvalues")
+  sumry[2, ] <- c("$lw", length(x$lw), mode(x$lw), paste("Row weigths (for", x$call[[2]], "cols)"))
+  sumry[3, ] <- c("$cw", length(x$cw), mode(x$cw), paste("Col weigths (for", x$call[[4]], "cols)"))
   
   print(sumry, quote = FALSE)
   cat("\n")
   sumry <- array("", c(11, 4), list(1:11, c("data.frame", "nrow", 
                                             "ncol", "content")))
-  sumry[1, ] <- c("$tab", nrow(x$tab), ncol(x$tab), "crossed array (CA)")
-  sumry[2, ] <- c("$li", nrow(x$li), ncol(x$li), "R col = CA row: coordinates")
-  sumry[3, ] <- c("$l1", nrow(x$l1), ncol(x$l1), "R col = CA row: normed scores")
-  sumry[4, ] <- c("$co", nrow(x$co), ncol(x$co), "Q col = CA column: coordinates")
-  sumry[5, ] <- c("$c1", nrow(x$c1), ncol(x$c1), "Q col = CA column: normed scores")
-  sumry[6, ] <- c("$lR", nrow(x$lR), ncol(x$lR), "row coordinates (R)")
-  sumry[7, ] <- c("$mR", nrow(x$mR), ncol(x$mR), "normed row scores (R)")
-  sumry[8, ] <- c("$lQ", nrow(x$lQ), ncol(x$lQ), "row coordinates (Q)")
-  sumry[9, ] <- c("$mQ", nrow(x$mQ), ncol(x$mQ), "normed row scores (Q)")
-  sumry[10, ] <- c("$aR", nrow(x$aR), ncol(x$aR), "axis onto rlq axis (R)")
-  sumry[11, ] <- c("$aQ", nrow(x$aQ), ncol(x$aQ), "axis onto rlq (Q)")
+  sumry[1, ] <- c("$tab", nrow(x$tab), ncol(x$tab), paste("Crossed Table (CT): cols(", x$call[[2]], ") x cols(", x$call[[4]], ")", sep=""))
+  sumry[2, ] <- c("$li", nrow(x$li), ncol(x$li), paste("CT row scores (cols of ", x$call[[2]], ")", sep=""))
+  sumry[3, ] <- c("$l1", nrow(x$l1), ncol(x$l1), paste("Principal components (loadings for ", x$call[[2]], " cols)", sep=""))
+  sumry[4, ] <- c("$co", nrow(x$co), ncol(x$co), paste("CT col scores (cols of ", x$call[[4]], ")", sep=""))
+  sumry[5, ] <- c("$c1", nrow(x$c1), ncol(x$c1), paste("Principal axes (loadings for ", x$call[[4]], " cols)", sep=""))
+  sumry[6, ] <- c("$lR", nrow(x$lR), ncol(x$lR), paste("Row scores (rows of ", x$call[[2]], ")", sep=""))
+  sumry[7, ] <- c("$mR", nrow(x$mR), ncol(x$mR), paste("Normed row scores (rows of ", x$call[[2]], ")", sep=""))
+  sumry[8, ] <- c("$lQ", nrow(x$lQ), ncol(x$lQ), paste("Row scores (rows of ", x$call[[4]], ")", sep=""))
+  sumry[9, ] <- c("$mQ", nrow(x$mQ), ncol(x$mQ), paste("Normed row scores (rows of ", x$call[[4]], ")", sep=""))
+  sumry[10, ] <- c("$aR", nrow(x$aR), ncol(x$aR), paste("Corr ", x$call[[2]], " axes / rlq axes", sep=""))
+  sumry[11, ] <- c("$aQ", nrow(x$aQ), ncol(x$aQ),  paste("Corr ", x$call[[3]], " axes / coinertia axes", sep=""))
   
   print(sumry, quote = FALSE)
   cat("\n")
@@ -144,6 +144,12 @@
 "summary.rlq" <- function (object, ...) {
   if (!inherits(object, "rlq")) 
     stop("to be used with 'rlq' object")
+
+  thetitle <- "RLQ analysis" 
+  cat(thetitle)
+  cat("\n\n")
+  NextMethod()
+  
   appel <- as.list(object$call)
   dudiL <- eval.parent(appel$dudiL)
   dudiR <- eval.parent(appel$dudiR)
@@ -163,28 +169,31 @@
   corr <- covar/sdR/sdQ
   U <- cbind.data.frame(eig, covar, sdR, sdQ, corr)
   row.names(U) <- as.character(1:object$nf)
+  res <- list(EigDec = U)
   cat("\nEigenvalues decomposition:\n")
   print(U)
-  cat("\nInertia & coinertia R:\n")
+  cat(paste("\nInertia & coinertia R (", deparse(appel$dudiR),"):\n", sep=""))
   inertia <- cumsum(sdR^2)
   max <- cumsum(dudiR$eig[1:object$nf])
   ratio <- inertia/max
   U <- cbind.data.frame(inertia, max, ratio)
   row.names(U) <- util(object$nf)
+  res$InerR <- U
   print(U)
-  cat("\nInertia & coinertia Q:\n")
+  cat(paste("\nInertia & coinertia Q (", deparse(appel$dudiR),"):\n", sep=""))
   inertia <- cumsum(sdQ^2)
   max <- cumsum(dudiQ$eig[1:object$nf])
   ratio <- inertia/max
   U <- cbind.data.frame(inertia, max, ratio)
   row.names(U) <- util(object$nf)
+  res$InerQ <- U
   print(U)
-  cat("\nCorrelation L:\n")
-
+  cat(paste("\nCorrelation L (", deparse(appel$dudiL),"):\n", sep=""))
   max <- sqrt(dudiL$eig[1:object$nf])
   ratio <- corr/max
   U <- cbind.data.frame(corr, max, ratio)
   row.names(U) <- 1:object$nf
+  res$CorL <- U
   print(U)
 }
 
